OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s has published the calendar »%s«",
    "Hello," : "Hello,",
    "We wanted to inform you that %s has published the calendar »%s«." : "We wanted to inform you that %s has published the calendar »%s«.",
    "Open »%s«" : "Open »%s«",
    "Cheers!" : "Cheers!",
    "Calendar" : "Calendar",
    "A Calendar app for Nextcloud" : "A Calendar app for Nextcloud",
    "Today" : "Today",
    "Day" : "Day",
    "Week" : "Week",
    "Month" : "Month",
    "List" : "List",
    "Download" : "Download",
    "Delete" : "Delete",
    "Share link" : "Share link",
    "Share with users or groups" : "Share with users or groups",
    "can edit" : "can edit",
    "New calendar" : "New calendar",
    "Filename" : "Filename",
    "Cancel" : "Cancel",
    "Automatic" : "Automatic",
    "or" : "or",
    "Actions" : "Actions",
    "Show week numbers" : "Show week numbers",
    "Settings & import" : "Settings & import",
    "Notification" : "Notification",
    "Email" : "Email",
    "Busy" : "Busy",
    "Unknown" : "Unknown",
    "All day" : "All day",
    "never" : "never",
    "after" : "after",
    "Repeat" : "Repeat",
    "Monday" : "Monday",
    "Summary" : "Summary",
    "More" : "More",
    "Save" : "Save",
    "Update" : "Update",
    "Personal" : "Personal",
    "Details" : "Details",
    "Attendees" : "Attendees",
    "Reminders" : "Reminders",
    "Close" : "Close",
    "Anniversary" : "Anniversary",
    "Week {number} of {year}" : "Week {number} of {year}",
    "Daily" : "Daily",
    "Weekly" : "Weekly",
    "next year" : "next year",
    "today" : "today",
    "When shared show full event" : "When shared show full event",
    "When shared show only busy" : "When shared show only busy",
    "When shared hide this event" : "When shared hide this event",
    "Location" : "Location",
    "Description" : "Description",
    "Status" : "Status",
    "Confirmed" : "Confirmed",
    "Tentative" : "Tentative",
    "Categories" : "Categories",
    "Presentation" : "Presentation",
    "Review" : "Review",
    "Office" : "Office",
    "Mail" : "Mail",
    "Play" : "Play",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");
